@@ -117,14 +117,14 @@ class BreakScreen(object):
         timeformat = '{:02d}:{:02d}'.format(mins, secs)
         GLib.idle_add(lambda: self.__update_count_down(timeformat))
 
-    def show_message(self, break_obj, widget):
+    def show_message(self, break_obj, widget, tray_actions=[]):
         """
         Show the break screen with the given message on all displays.
         """
         message = break_obj.name
         image_path = break_obj.image
         self.enable_shortcut = not self.strict_break and self.shortcut_disable_time <= 0
-        GLib.idle_add(lambda: self.__show_break_screen(message, image_path, widget))
+        GLib.idle_add(lambda: self.__show_break_screen(message, image_path, widget, tray_actions))
 
     def close(self):
         """
@@ -136,13 +136,20 @@ class BreakScreen(object):
         # Destroy other windows if exists
         GLib.idle_add(lambda: self.__destroy_all_screens())
 
-    def __show_break_screen(self, message, image_path, widget):
+    def __tray_action(self, button, tray_action):
+        """
+        Tray action handler.
+        Hides the toolbar button and call the action provided by the plugin.
+        """
+        button.hide()
+        tray_action.action()
+
+    def __show_break_screen(self, message, image_path, widget, tray_actions):
         """
         Show an empty break screen on all screens.
         """
         # Lock the keyboard
-        thread = threading.Thread(target=self.__lock_keyboard)
-        thread.start()
+        Utility.start_thread(self.__lock_keyboard)
 
         screen = Gtk.Window().get_screen()
         no_of_monitors = screen.get_n_monitors()
@@ -163,6 +170,18 @@ class BreakScreen(object):
             lbl_widget = builder.get_object("lbl_widget")
             img_break = builder.get_object("img_break")
             box_buttons = builder.get_object("box_buttons")
+            toolbar = builder.get_object("toolbar")
+
+            for tray_action in tray_actions:
+                toolbar_button = None
+                if isinstance(tray_action.icon, str):
+                    toolbar_button = Gtk.ToolButton.new_from_stock(tray_action.icon)
+                else:
+                    toolbar_button = Gtk.ToolButton.new(tray_action.icon, tray_action.name)
+                toolbar_button.connect("clicked", lambda button, action: self.__tray_action(button, action), tray_action)
+                toolbar_button.set_tooltip_text(_(tray_action.name))
+                toolbar.add(toolbar_button)
+                toolbar_button.show()
 
             # Add the buttons
             if not self.strict_break:
