@@ -37,6 +37,7 @@ import gi
 gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 from gi.repository import GLib
+from gi.repository import GdkPixbuf
 
 gi.require_version('Gdk', '3.0')
 
@@ -80,7 +81,7 @@ def start_thread(target_function, **args):
     """
     Execute the function in a separate thread.
     """
-    thread = threading.Thread(target=target_function, kwargs=args)
+    thread = threading.Thread(target=target_function, name="WorkThread", kwargs=args)
     thread.start()
 
 
@@ -342,6 +343,14 @@ def initialize_safeeyes():
         shutil.copy2(SYSTEM_STYLE_SHEET_PATH, STYLE_SHEET_PATH)
 
 
+def replace_style_sheet():
+    """
+    Replace the user style sheet by system style sheet.
+    """
+    delete(STYLE_SHEET_PATH)
+    shutil.copy2(SYSTEM_STYLE_SHEET_PATH, STYLE_SHEET_PATH)
+
+
 def intialize_logging(debug):
     """
     Initialize the logging framework using the Safe Eyes specific configurations.
@@ -497,3 +506,15 @@ def create_gtk_builder(glade_file):
             if title is not None:
                 obj.set_title(_(title))
     return builder
+
+
+def load_and_scale_image(path, width, height):
+    if not os.path.isfile(path):
+        return None
+    pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_scale(
+        filename=path,
+        width=width,
+        height=height,
+        preserve_aspect_ratio=True)
+    image = Gtk.Image.new_from_pixbuf(pixbuf)
+    return image
