@@ -42,12 +42,13 @@ class SettingsDialog(object):
     """
         Create and initialize SettingsDialog instance.
     """
+
     def __init__(self, config, on_save_settings):
         self.config = config
         self.on_save_settings = on_save_settings
         self.plugin_switches = {}
         self.plugin_map = {}
-        self.last_short_break_interval = config.get('break_interval')
+        self.last_short_break_interval = config.get('short_break_interval')
         self.initializing = True
         self.infobar_long_break_shown = False
 
@@ -82,8 +83,8 @@ class SettingsDialog(object):
         # Set the current values of input fields
         self.spin_short_break_duration.set_value(config.get('short_break_duration'))
         self.spin_long_break_duration.set_value(config.get('long_break_duration'))
-        self.spin_short_break_interval.set_value(config.get('break_interval'))
-        self.spin_long_break_interval.set_value(config.get('no_of_short_breaks_per_long_break') * config.get('break_interval'))
+        self.spin_short_break_interval.set_value(config.get('short_break_interval'))
+        self.spin_long_break_interval.set_value(config.get('long_break_interval'))
         self.spin_time_to_prepare.set_value(config.get('pre_break_warning_time'))
         self.spin_postpone_duration.set_value(config.get('postpone_duration'))
         self.spin_disable_keyboard_shortcut.set_value(config.get('shortcut_disable_time'))
@@ -118,16 +119,48 @@ class SettingsDialog(object):
                 break_config,
                 is_short,
                 self.config,
-                lambda: parent_box.remove(box),
                 lambda cfg: lbl_name.set_label(_(cfg['name'])),
                 lambda is_short,
                 break_config: self.__create_break_item(break_config, is_short)
             )
         )
+        btn_delete = builder.get_object('btn_delete')
+        btn_delete.connect(
+            'clicked',
+            lambda button: self.__delete_break(
+                break_config,
+                is_short,
+                lambda: parent_box.remove(box),
+            )
+        )
         box.set_visible(True)
         parent_box.pack_start(box, False, False, 0)
         return box
 
+    def __delete_break(self, break_config, is_short, on_remove):
+        """
+        Remove the break after a confirmation.
+        """
+
+        def __confirmation_dialog_response(widget, response_id):
+            if response_id == Gtk.ResponseType.OK:
+                if is_short:
+                    self.config.get('short_breaks').remove(break_config)
+                else:
+                    self.config.get('long_breaks').remove(break_config)
+                on_remove()
+            widget.destroy()
+
+        messagedialog = Gtk.MessageDialog(parent=self.window,
+                                          flags=Gtk.DialogFlags.MODAL,
+                                          type=Gtk.MessageType.WARNING,
+                                          buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
+                                                   _("Delete"), Gtk.ResponseType.OK),
+                                          message_format=_("Are you sure you want to delete this break?"))
+        messagedialog.connect("response", __confirmation_dialog_response)
+        messagedialog.format_secondary_text(_("You can't undo this action."))
+        messagedialog.show()
+
     def __create_plugin_item(self, plugin_config):
         """
         Create an entry for plugin to be listed in the plugin tab.
@@ -167,11 +200,11 @@ class SettingsDialog(object):
         dialog = PluginSettingsDialog(plugin_config)
         dialog.show()
 
-    def __show_break_properties_dialog(self, break_config, is_short, parent, on_remove, on_close, on_add):
+    def __show_break_properties_dialog(self, break_config, is_short, parent, on_close, on_add):
         """
         Show the BreakProperties dialog
         """
-        dialog = BreakSettingsDialog(break_config, is_short, parent, self.plugin_map, on_remove, on_close, on_add)
+        dialog = BreakSettingsDialog(break_config, is_short, parent, self.plugin_map, on_close, on_add)
         dialog.show()
 
     def show(self):
@@ -237,8 +270,8 @@ class SettingsDialog(object):
         """
         self.config.set('short_break_duration', self.spin_short_break_duration.get_value_as_int())
         self.config.set('long_break_duration', self.spin_long_break_duration.get_value_as_int())
-        self.config.set('break_interval', self.spin_short_break_interval.get_value_as_int())
-        self.config.set('no_of_short_breaks_per_long_break', math.floor(self.spin_long_break_interval.get_value_as_int() / self.spin_short_break_interval.get_value_as_int()))
+        self.config.set('short_break_interval', self.spin_short_break_interval.get_value_as_int())
+        self.config.set('long_break_interval', self.spin_long_break_interval.get_value_as_int())
         self.config.set('pre_break_warning_time', self.spin_time_to_prepare.get_value_as_int())
         self.config.set('postpone_duration', self.spin_postpone_duration.get_value_as_int())
         self.config.set('shortcut_disable_time', self.spin_disable_keyboard_shortcut.get_value_as_int())
@@ -257,6 +290,7 @@ class PluginSettingsDialog(object):
     """
     Builds a settings dialog based on the configuration of a plugin.
     """
+
     def __init__(self, config):
         self.config = config
         self.property_controls = []
@@ -333,11 +367,11 @@ class BreakSettingsDialog(object):
     """
     Builds a settings dialog based on the configuration of a plugin.
     """
-    def __init__(self, break_config, is_short, parent_config, plugin_map, on_remove, on_close, on_add):
+
+    def __init__(self, break_config, is_short, parent_config, plugin_map, on_close, on_add):
         self.break_config = break_config
         self.parent_config = parent_config
         self.plugin_check_buttons = {}
-        self.on_remove = on_remove
         self.on_close = on_close
         self.is_short = is_short
         self.on_add = on_add
@@ -346,30 +380,39 @@ class BreakSettingsDialog(object):
         builder.connect_signals(self)
         self.window = builder.get_object('dialog_settings_break')
         self.txt_break = builder.get_object('txt_break')
+        self.switch_override_interval = builder.get_object('switch_override_interval')
         self.switch_override_duration = builder.get_object('switch_override_duration')
         self.switch_override_plugins = builder.get_object('switch_override_plugins')
+        self.spin_interval = builder.get_object('spin_interval')
         self.spin_duration = builder.get_object('spin_duration')
         self.img_break = builder.get_object('img_break')
         self.cmb_type = builder.get_object('cmb_type')
-        # User cannot remove the last break
-        not_last_break = (len(parent_config.get('short_breaks')) + len(parent_config.get('long_breaks'))) > 1
-        builder.get_object('btn_remove').set_sensitive(not_last_break)
 
         grid_plugins = builder.get_object('grid_plugins')
         list_types = builder.get_object('lst_break_types')
 
+        interval_overriden = break_config.get('interval', None) is not None
         duration_overriden = break_config.get('duration', None) is not None
         plugins_overriden = break_config.get('plugins', None) is not None
 
         # Set the values
         self.window.set_title(_('Break Settings'))
         self.txt_break.set_text(_(break_config['name']))
+        self.switch_override_interval.set_active(interval_overriden)
         self.switch_override_duration.set_active(duration_overriden)
         self.switch_override_plugins.set_active(plugins_overriden)
         self.cmb_type.set_active(0 if is_short else 1)
         list_types[0][0] = _(list_types[0][0])
         list_types[1][0] = _(list_types[1][0])
 
+        if interval_overriden:
+            self.spin_interval.set_value(break_config['interval'])
+        else:
+            if is_short:
+                self.spin_interval.set_value(parent_config.get('short_break_interval'))
+            else:
+                self.spin_interval.set_value(parent_config.get('long_break_interval'))
+
         if duration_overriden:
             self.spin_duration.set_value(break_config['duration'])
         else:
@@ -393,11 +436,19 @@ class BreakSettingsDialog(object):
                 row = 0
         # GtkSwitch state-set signal is available only from 3.14
         if Gtk.get_minor_version() >= 14:
+            self.switch_override_interval.connect('state-set', self.on_switch_override_interval_activate)
             self.switch_override_duration.connect('state-set', self.on_switch_override_duration_activate)
             self.switch_override_plugins.connect('state-set', self.on_switch_override_plugins_activate)
+            self.on_switch_override_interval_activate(self.switch_override_interval, self.switch_override_interval.get_active())
             self.on_switch_override_duration_activate(self.switch_override_duration, self.switch_override_duration.get_active())
             self.on_switch_override_plugins_activate(self.switch_override_plugins, self.switch_override_plugins.get_active())
 
+    def on_switch_override_interval_activate(self, switch_button, state):
+        """
+        switch_override_interval state change event handler.
+        """
+        self.spin_interval.set_sensitive(state)
+
     def on_switch_override_duration_activate(self, switch_button, state):
         """
         switch_override_duration state change event handler.
@@ -415,8 +466,7 @@ class BreakSettingsDialog(object):
         """
         Show a file chooser dialog and let the user to select an image.
         """
-        dialog = Gtk.FileChooserDialog(_('Please select an image'), self.window, Gtk.FileChooserAction.OPEN, (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
-                                       Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
+        dialog = Gtk.FileChooserDialog(_('Please select an image'), self.window, Gtk.FileChooserAction.OPEN, (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
 
         png_filter = Gtk.FileFilter()
         png_filter.set_name("PNG files")
@@ -435,17 +485,6 @@ class BreakSettingsDialog(object):
 
         dialog.destroy()
 
-    def remove_break(self, button):
-        """
-        Remove the break
-        """
-        if self.is_short:
-            self.parent_config.get('short_breaks').remove(self.break_config)
-        else:
-            self.parent_config.get('long_breaks').remove(self.break_config)
-        self.on_remove()
-        self.window.destroy()
-
     def on_window_delete(self, *args):
         """
         Event handler for Properties dialog close action.
@@ -453,6 +492,10 @@ class BreakSettingsDialog(object):
         break_name = self.txt_break.get_text().strip()
         if break_name:
             self.break_config['name'] = break_name
+        if self.switch_override_interval.get_active():
+            self.break_config['interval'] = int(self.spin_interval.get_value())
+        else:
+            self.break_config.pop('interval', None)
         if self.switch_override_duration.get_active():
             self.break_config['duration'] = int(self.spin_duration.get_value())
         else:
@@ -493,6 +536,7 @@ class NewBreakDialog(object):
     """
     Builds a new break dialog.
     """
+
     def __init__(self, parent_config, on_add):
         self.parent_config = parent_config
         self.on_add = on_add
